EnableDirectionControl

Trait EnableDirectionControl 

pub trait EnableDirectionControl<Resources> {
    type WithDirectionControl: SetDirection;

    // Required method
    fn enable_direction_control(
        self,
        res: Resources,
    ) -> Self::WithDirectionControl;
}
Enable direction control for a driver

The Resources type parameter defines the hardware resources required for direction control.

Required Associated Types

type WithDirectionControl: SetDirection

The type of the driver after direction control has been enabled

Required Methods

fn enable_direction_control(self, res: Resources) -> Self::WithDirectionControl

Enable direction control

Implementors

Source

impl<EnableFault, StandbyReset, Mode1, Mode2, StepMode3, DirMode4, OutputPinError> EnableDirectionControl<DirMode4> for STSPIN220<EnableFault, StandbyReset, Mode1, Mode2, StepMode3, ()>
where DirMode4: OutputPin<Error = OutputPinError>,

Source

type WithDirectionControl = STSPIN220<EnableFault, StandbyReset, Mode1, Mode2, StepMode3, DirMode4>

Source

impl<Reset, Mode0, Mode1, Mode2, Step, Dir, OutputPinError> EnableDirectionControl<Dir> for DRV8825<(), (), (), Reset, Mode0, Mode1, Mode2, Step, ()>
where Dir: OutputPin<Error = OutputPinError>,

Source

type WithDirectionControl = DRV8825<(), (), (), Reset, Mode0, Mode1, Mode2, Step, Dir>

Source

impl<Step, Dir, OutputPinError> EnableDirectionControl<Dir> for DQ542MA<(), Step, ()>
where Dir: OutputPin<Error = OutputPinError>,