pub trait EnableDirectionControl<Resources> {
type WithDirectionControl: SetDirection;
// Required method
fn enable_direction_control(
self,
res: Resources,
) -> Self::WithDirectionControl;
}Expand description
Enable direction control for a driver
The Resources type parameter defines the hardware resources required for
direction control.
Required Associated Types
Sourcetype WithDirectionControl: SetDirection
type WithDirectionControl: SetDirection
The type of the driver after direction control has been enabled
Required Methods
Sourcefn enable_direction_control(self, res: Resources) -> Self::WithDirectionControl
fn enable_direction_control(self, res: Resources) -> Self::WithDirectionControl
Enable direction control